@@ -1,7 +1,7 @@
 //clients.c:
 
 /*
- *      Copyright (C) Philipp 'ph3-der-loewe' Schafft - 2010-2011
+ *      Copyright (C) Philipp 'ph3-der-loewe' Schafft - 2010-2013
  *
  *  This file is part of RoarD,
  *  a sound server daemon for using the RoarAudio protocol.
@@ -131,251 +131,241 @@ int muroard_client_handle(int id) {
  }
 
  if ( m.stream > MUROARD_MAX_STREAMS && m.stream != (uint16_t)-1 ) {
-  // FIXME: this code is redundant :(
-  m.cmd     = MUROAR_CMD_ERROR;
-  m.stream  = -1;
-  m.pos     =  0;
-  m.datalen =  0;
-
-  if ( muroard_proto_send(sock, &m) == -1 ) {
-   muroard_client_delete(id);
-   return -1;
-  }
-  return 0;
- }
-
- switch (m.cmd) {
-  case MUROAR_CMD_NOOP:
-  case MUROAR_CMD_IDENTIFY:
-  case MUROAR_CMD_AUTH:
+  ret = -1;
+ } else {
+  switch (m.cmd) {
+   case MUROAR_CMD_NOOP:
+   case MUROAR_CMD_IDENTIFY:
+   case MUROAR_CMD_AUTH:
 #ifdef MUROARD_FEATURE_NOOP_SIUCMDS
-  case MUROAR_CMD_SET_META:
+   case MUROAR_CMD_SET_META:
 #endif
-    // no need to do anything
-    m.datalen =  0;
-   break;
-  case MUROAR_CMD_QUIT:
-    m.cmd = MUROAR_CMD_OK;
-    m.datalen =  0;
-    muroard_proto_send(sock, &m);
-    muroard_client_delete(id);
-    return 0;
-   break;
-  case MUROAR_CMD_EXEC_STREAM:
-    m.datalen =  0;
-    if ( m.stream != (uint16_t)-1 && m.stream == muroard_state_member(client)[id].stream ) {
-     if ( muroard_stream_exec(m.stream) == -1 )
+     // no need to do anything
+     m.datalen =  0;
+    break;
+   case MUROAR_CMD_QUIT:
+     m.cmd = MUROAR_CMD_OK;
+     m.datalen =  0;
+     muroard_proto_send(sock, &m);
+     muroard_client_delete(id);
+     return 0;
+    break;
+   case MUROAR_CMD_EXEC_STREAM:
+     m.datalen =  0;
+     if ( m.stream != (uint16_t)-1 && m.stream == muroard_state_member(client)[id].stream ) {
+      if ( muroard_stream_exec(m.stream) == -1 )
+       ret = -1;
+     } else {
       ret = -1;
-    } else {
-     ret = -1;
-    }
-   break;
+     }
+    break;
 #ifdef MUROARD_FEATURE_CMD_WHOAMI
-  case MUROAR_CMD_WHOAMI:
-    m.datalen =  1;
-    m.data[0] =  id;
-   break;
+   case MUROAR_CMD_WHOAMI:
+     m.datalen =  1;
+     m.data[0] =  id;
+    break;
 #endif
 #ifdef MUROARD_FEATURE_CMD_EXIT
-  case MUROAR_CMD_EXIT:
-    // we simply set muroard_state_member(alive) to zero so we will die with the next cycle.
-    if ( m.datalen == 0 ) { // default: exit
-     muroard_state_member(alive)  = 0;
-    } else if ( m.datalen == 1 && m.data[0] == 0 ) { // explicit: exit
-     muroard_state_member(alive)  = 0;
+   case MUROAR_CMD_EXIT:
+     // we simply set muroard_state_member(alive) to zero so we will die with the next cycle.
+     if ( m.datalen == 0 ) { // default: exit
+      muroard_state_member(alive)  = 0;
+     } else if ( m.datalen == 1 && m.data[0] == 0 ) { // explicit: exit
+      muroard_state_member(alive)  = 0;
 #ifndef MUROARD_FEATURE_TERMINATE
-    } else if ( m.datalen == 1 && m.data[0] == 1 ) { // explicit: terminate
-     ret = muroard_network_prefree();
+     } else if ( m.datalen == 1 && m.data[0] == 1 ) { // explicit: terminate
+      ret = muroard_network_prefree();
 #endif
-    } else { // terminate or unsupported command version
-     ret      = -1;
-    }
-    m.datalen = 0;
-   break;
+     } else { // terminate or unsupported command version
+      ret      = -1;
+     }
+     m.datalen = 0;
+    break;
 #endif
 #ifdef MUROARD_FEATURE_STANDBY
-  case MUROAR_CMD_SET_STANDBY:
-    if ( m.datalen != 2 ) {
-     ret = -1;
-    } else {
-     if ( m.data[0] != 0 ) {
+   case MUROAR_CMD_SET_STANDBY:
+     if ( m.datalen != 2 ) {
       ret = -1;
      } else {
-      switch (m.data[1]) {
-       case 0: muroard_waveform_standby(0, -1); break;
-       case 1: muroard_waveform_standby(1, -1); break;
-       default: ret = -1;
+      if ( m.data[0] != 0 ) {
+       ret = -1;
+      } else {
+       switch (m.data[1]) {
+        case 0: muroard_waveform_standby(0, -1); break;
+        case 1: muroard_waveform_standby(1, -1); break;
+        default: ret = -1;
+       }
       }
      }
-    }
-   break;
+    break;
 #endif
 #ifdef MUROARD_FEATURE_CMD_GET_STANDBY
-  case MUROAR_CMD_GET_STANDBY:
-    m.datalen = 2;
-    m.data[0] = 0;
+   case MUROAR_CMD_GET_STANDBY:
+     m.datalen = 2;
+     m.data[0] = 0;
 #ifdef MUROARD_FEATURE_STANDBY
-    m.data[1] = muroard_waveform_standby(-1, -1);
+     m.data[1] = muroard_waveform_standby(-1, -1);
 #else
-    m.data[1] = 0;
+     m.data[1] = 0;
 #endif
-   break;
+    break;
 #endif
 #ifdef MUROARD_FEATURE_CMD_GET_VOL
-  case MUROAR_CMD_GET_VOL:
-    // we support only the most up to date version of the command:
-    if ( m.datalen < 2 || m.data[0] != 0 || m.data[1] != 1 || m.stream == (uint16_t)-1 ) {
-     ret = -1;
-    } else {
-     m.datalen = 6*2;
-     // version: 1
-     m.data[ 0] = 0;
-     m.data[ 1] = 1;
-     // channels: 1
-     m.data[ 2] = 0;
-     m.data[ 3] = 1;
-     // scale:
-     m.data[ 4] = 0xFF;
-     m.data[ 5] = 0xFF;
-     // rpg mul:
-     m.data[ 6] = 0;
-     m.data[ 7] = 1;
-     // rpg div:
-     m.data[ 8] = 0;
-     m.data[ 9] = 1;
-     // our only channel:
-#ifdef MUROARD_FEATURE_VOLUME_CONTROL
-     volume = muroard_stream_get_volume(m.stream);
-     m.data[10] = (volume & 0xFF00) >> 8;
-     m.data[11] =  volume & 0x00FF;
-#else
-     m.data[10] = 0xFF;
-     m.data[11] = 0xFF;
-#endif
-    }
-   break;
-#endif
-#ifdef MUROARD_FEATURE_VOLUME_CONTROL
-  case MUROAR_CMD_SET_VOL:
-    if ( m.datalen < (4*2) || m.data[0] != 0 || m.data[1] != 1 || !muroard_stream_exist(m.stream) ) {
-     ret = -1;
-    } else {
-     channels = (m.datalen - 3*2)/2;
-     volume = 0;
-     tmp = ntohs(((uint16_t*)m.data)[2]);
-     ret = 0;
-     switch (tmp) {
-      case 1: // ROAR_SET_VOL_ALL
-      case 4: // ROAR_SET_VOL_UNMAPPED
-        switch (channels) {
-         case 1: // mono
-           volume = ntohs(((uint16_t*)m.data)[3]);
-          break;
-         case 2: // stereo
-           volume = ((uint_least32_t)ntohs(((uint16_t*)m.data)[3]) + (uint_least32_t)ntohs(((uint16_t*)m.data)[4]))/2;
-//           printf("l=%u, r=%u, avg=%u\n", (unsigned)ntohs(((uint16_t*)m.data)[3]), (unsigned)ntohs(((uint16_t*)m.data)[4]), (unsigned)volume);
-          break;
-         default:
-           ret = -1;
-          break;
-        }
-       break;
-      case 3: // ROAR_SET_VOL_MS
-        if ( channels == 1 ) {
-         volume = ntohs(((uint16_t*)m.data)[3]);
-        } else {
-         ret = -1;
-        }
-       break;
-      default:
-        ret = -1;
-       break;
-     }
-
-//     printf("ret=%i, volume=%u\n", ret, (unsigned)volume);
-     tmp    = ntohs(((uint16_t*)m.data)[1]);
-     volume = (float)volume*65535.f/(float)tmp;
-//     printf("tmp=%u, volume=%u\n", (unsigned)tmp, (unsigned)volume);
-     muroard_state_member(stream)[m.stream].volume = volume;
-    }
-   break;
-#endif
-#ifdef MUROARD_FEATURE_CMD_KICK
-  case MUROAR_CMD_KICK:
-    if ( m.datalen != 4 ) {
-     ret = -1;
-    } else {
-     if ( m.data[0] != 0 ) { // type >= 256
+   case MUROAR_CMD_GET_VOL:
+     // we support only the most up to date version of the command:
+     if ( m.datalen < 2 || m.data[0] != 0 || m.data[1] != 1 || m.stream == (uint16_t)-1 ) {
       ret = -1;
      } else {
-      if ( m.data[2] != 0 ) { // id >= 256
-       ret = -1;
-      } else if ( m.data[1] == 1 ) { // CLIENT
-       ret = muroard_client_delete(m.data[3]);
-      } else if ( m.data[1] == 2 ) { // STREAM
-       ret = muroard_stream_delete(m.data[3]);
-      } else { // unknown type
+      m.datalen = 6*2;
+      // version: 1
+      m.data[ 0] = 0;
+      m.data[ 1] = 1;
+      // channels: 1
+      m.data[ 2] = 0;
+      m.data[ 3] = 1;
+      // scale:
+      m.data[ 4] = 0xFF;
+      m.data[ 5] = 0xFF;
+      // rpg mul:
+      m.data[ 6] = 0;
+      m.data[ 7] = 1;
+      // rpg div:
+      m.data[ 8] = 0;
+      m.data[ 9] = 1;
+      // our only channel:
+#ifdef MUROARD_FEATURE_VOLUME_CONTROL
+      volume = muroard_stream_get_volume(m.stream);
+      m.data[10] = (volume & 0xFF00) >> 8;
+      m.data[11] =  volume & 0x00FF;
+#else
+      m.data[10] = 0xFF;
+      m.data[11] = 0xFF;
+#endif
+     }
+    break;
+#endif
+#ifdef MUROARD_FEATURE_VOLUME_CONTROL
+   case MUROAR_CMD_SET_VOL:
+     if ( m.datalen < (4*2) || m.data[0] != 0 || m.data[1] != 1 || !muroard_stream_exist(m.stream) ) {
+      ret = -1;
+     } else {
+      channels = (m.datalen - 3*2)/2;
+      volume = 0;
+      tmp = ntohs(((uint16_t*)m.data)[2]);
+      ret = 0;
+      switch (tmp) {
+       case 1: // ROAR_SET_VOL_ALL
+       case 4: // ROAR_SET_VOL_UNMAPPED
+         switch (channels) {
+          case 1: // mono
+            volume = ntohs(((uint16_t*)m.data)[3]);
+           break;
+          case 2: // stereo
+            volume = ((uint_least32_t)ntohs(((uint16_t*)m.data)[3]) + (uint_least32_t)ntohs(((uint16_t*)m.data)[4]))/2;
+ //           printf("l=%u, r=%u, avg=%u\n", (unsigned)ntohs(((uint16_t*)m.data)[3]), (unsigned)ntohs(((uint16_t*)m.data)[4]), (unsigned)volume);
+           break;
+          default:
+            ret = -1;
+           break;
+         }
+        break;
+       case 3: // ROAR_SET_VOL_MS
+         if ( channels == 1 ) {
+          volume = ntohs(((uint16_t*)m.data)[3]);
+         } else {
+          ret = -1;
+         }
+        break;
+       default:
+         ret = -1;
+        break;
+      }
+ 
+ //     printf("ret=%i, volume=%u\n", ret, (unsigned)volume);
+      tmp    = ntohs(((uint16_t*)m.data)[1]);
+      volume = (float)volume*65535.f/(float)tmp;
+ //     printf("tmp=%u, volume=%u\n", (unsigned)tmp, (unsigned)volume);
+      muroard_state_member(stream)[m.stream].volume = volume;
+     }
+    break;
+#endif
+#ifdef MUROARD_FEATURE_CMD_KICK
+   case MUROAR_CMD_KICK:
+     if ( m.datalen != 4 ) {
+      ret = -1;
+     } else {
+      if ( m.data[0] != 0 ) { // type >= 256
        ret = -1;
+      } else {
+       if ( m.data[2] != 0 ) { // id >= 256
+        ret = -1;
+       } else if ( m.data[1] == 1 ) { // CLIENT
+        ret = muroard_client_delete(m.data[3]);
+       } else if ( m.data[1] == 2 ) { // STREAM
+        ret = muroard_stream_delete(m.data[3]);
+       } else { // unknown type
+        ret = -1;
+       }
       }
      }
-    }
-   break;
+    break;
 #endif
 #ifdef MUROARD_FEATURE_CMD_ATTACH
-  case MUROAR_CMD_ATTACH:
-    ret = muroard_client_handle_attach(id, &m);
-   break;
+   case MUROAR_CMD_ATTACH:
+     ret = muroard_client_handle_attach(id, &m);
+    break;
 #endif
 #ifdef MUROARD_FEATURE_CMD_SERVER_OINFO
-  case MUROAR_CMD_SERVER_OINFO:
-    ret = muroard_client_handle_server_oinfo(id, &m);
-   break;
+   case MUROAR_CMD_SERVER_OINFO:
+     ret = muroard_client_handle_server_oinfo(id, &m);
+    break;
 #endif
 #ifdef MUROARD_FEATURE_CMD_PASSFH
-  case MUROAR_CMD_PASSFH:
-    ret = muroard_client_handle_passfh(id, &m);
-   break;
+   case MUROAR_CMD_PASSFH:
+     ret = muroard_client_handle_passfh(id, &m);
+    break;
 #endif
 #ifdef MUROARD_FEATURE_CMD_LIST_CLIENTS
-  case MUROAR_CMD_LIST_CLIENTS:
-    ret = muroard_client_handle_list_clients(id, &m);
-   break;
+   case MUROAR_CMD_LIST_CLIENTS:
+     ret = muroard_client_handle_list_clients(id, &m);
+    break;
 #endif
 #ifdef MUROARD_FEATURE_CMD_LIST_STREAMS
-  case MUROAR_CMD_LIST_STREAMS:
-    ret = muroard_client_handle_list_streams(id, &m);
-   break;
+   case MUROAR_CMD_LIST_STREAMS:
+     ret = muroard_client_handle_list_streams(id, &m);
+    break;
 #endif
 #ifdef MUROARD_FEATURE_CMD_GET_CLIENT
-  case MUROAR_CMD_GET_CLIENT:
-    ret = muroard_client_handle_get_client(id, &m);
-   break;
+   case MUROAR_CMD_GET_CLIENT:
+     ret = muroard_client_handle_get_client(id, &m);
+    break;
 #endif
 #ifdef MUROARD_FEATURE_CMD_GET_STREAM
-  case MUROAR_CMD_GET_STREAM:
-    ret = muroard_client_handle_get_stream(id, &m);
-   break;
+   case MUROAR_CMD_GET_STREAM:
+     ret = muroard_client_handle_get_stream(id, &m);
+    break;
 #endif
 #ifdef MUROARD_FEATURE_CMD_CAPS
-  case MUROAR_CMD_CAPS:
-    ret = muroard_client_handle_caps(id, &m);
-   break;
+   case MUROAR_CMD_CAPS:
+     ret = muroard_client_handle_caps(id, &m);
+    break;
 #endif
 #ifdef MUROARD_FEATURE_CMD_SERVER_INFO
-  case MUROAR_CMD_SERVER_INFO:
-    ret = muroard_client_handle_server_info(id, &m);
-   break;
+   case MUROAR_CMD_SERVER_INFO:
+     ret = muroard_client_handle_server_info(id, &m);
+    break;
 #endif
 #ifdef MUROARD_FEATURE_CMD_GETTIMEOFDAY
-  case MUROAR_CMD_GETTIMEOFDAY:
-    ret = muroard_client_handle_gettimeofday(id, &m);
-   break;
+   case MUROAR_CMD_GETTIMEOFDAY:
+     ret = muroard_client_handle_gettimeofday(id, &m);
+    break;
 #endif
-  case MUROAR_CMD_NEW_STREAM:
-    ret = muroard_client_handle_new_stream(id, &m);
-   break;
-  default:
-    ret = -1; // we do not know this command
+   case MUROAR_CMD_NEW_STREAM:
+     ret = muroard_client_handle_new_stream(id, &m);
+    break;
+   default:
+     ret = -1; // we do not know this command
+  }
  }
 
  if ( ret == 0 ) {
