@@ -1,7 +1,7 @@
 //clients.h:
 
 /*
- *      Copyright (C) Philipp 'ph3-der-loewe' Schafft - 2010-2011
+ *      Copyright (C) Philipp 'ph3-der-loewe' Schafft - 2010-2013
  *
  *  This file is part of RoarD,
  *  a sound server daemon for using the RoarAudio protocol.
@@ -85,8 +85,10 @@ int muroard_client_handle_gettimeofday(int id, struct muroard_message * mes);
 
 #define client_get_sock(id)      (muroard_state_member(client)[(id)].state == CLIENT_STATE_UNUSED ? -1 : muroard_state_member(client)[(id)].sock)
 #define client_get_stream(id)    (muroard_state_member(client)[(id)].state == CLIENT_STATE_UNUSED ? -1 : muroard_state_member(client)[(id)].stream)
-#define client_set_stream(id, s) (muroard_state_member(client)[(id)].state == CLIENT_STATE_UNUSED || muroard_state_member(client)[(id)].stream != -1 ? \
-                                  -1 : (muroard_state_member(client)[(id)].stream = (s)) && 0)
+#define client_set_stream_check(id, s) (muroard_state_member(client)[(id)].state == CLIENT_STATE_UNUSED || \
+                                        muroard_state_member(client)[(id)].stream != -1 ? -1 : 0)
+#define client_set_stream(id, s) (client_set_stream_check((id),(s)) == -1 ? -1 : \
+                                  (muroard_state_member(client)[(id)].stream = (s)) && 0)
 
 #endif
 
