@@ -1,7 +1,7 @@
 //driver_muroar.c:
 
 /*
- *      Copyright (C) Philipp 'ph3-der-loewe' Schafft - 2010-2011
+ *      Copyright (C) Philipp 'ph3-der-loewe' Schafft - 2010-2013
  *
  *  This file is part of RoarD,
  *  a sound server daemon for using the RoarAudio protocol.
@@ -31,8 +31,6 @@
 #define DRIVER_HAVE_FREE
 #define DRIVER_HAVE_WRITE
 
-/* TODO: FIXME: this driver needs error handlung! */
-
 int muroard_driver_init(const char * dev) {
  struct sio_par par;
 
@@ -73,9 +71,7 @@ ssize_t muroard_driver_write(int16_t * data, size_t len, enum muroard_blocking b
  if ( blocking == MUROARD_BLOCKING_NONE )
   return -1;
 
- sio_write(muroard_state_member(driver_vp), data, len);
-
- return 0;
+ return (ssize_t)sio_write(muroard_state_member(driver_vp), data, len);
 }
 
 //ll
