@@ -1,7 +1,7 @@
 //muroard.c:
 
 /*
- *      Copyright (C) Philipp 'ph3-der-loewe' Schafft - 2010-2011
+ *      Copyright (C) Philipp 'ph3-der-loewe' Schafft - 2010-2013
  *
  *  This file is part of RoarD,
  *  a sound server daemon for using the RoarAudio protocol.
@@ -91,7 +91,7 @@ void muroard_usage (void) {
         " -sC CHANS             - Set source number of channels\n"
         " -sB BITS              - Set source number of bits\n"
         " -sE CODEC             - Set source codec (no symbolic names)\n"
-//        " -sD DIR               - Set source direction: in or out\n"
+        " -sD DIR               - Set source direction: in or out\n"
        );
 #endif
 
@@ -240,16 +240,21 @@ void muroard_shutdown(void) {
 }
 
 int muroard_main_initonly (int argc, char * argv[]) {
+#ifdef __WIN32
+#define __check_argc(num) if ( (argc - i) <= (num) ) { return 64; }
+#else
+#define __check_argc(num) if ( (argc - i) <= (num) ) { errno = EINVAL; return 64; }
+#endif
 #ifdef MUROARD_FEATURE_SOCKET_LISTEN
- int    n_type = MUROARD_DEFAULT_LISTEN_TYPE;
- char * n_addr = NULL; // use defualts from network module
- int    n_port = MUROARD_DEFAULT_LISTEN_PORT;
- int    n_no_listen = 0;
+ int          n_type = MUROARD_DEFAULT_LISTEN_TYPE;
+ const char * n_addr = NULL; // use defualts from network module
+ int          n_port = MUROARD_DEFAULT_LISTEN_PORT;
+ int          n_no_listen = 0;
 #endif
 #ifdef MUROARD_FEATURE_ARGV
  int i;
- char * k;
- char * o_dev = MUROARD_DEFAULT_DRIVER_DEV;
+ const char * k;
+ const char * o_dev = MUROARD_DEFAULT_DRIVER_DEV;
 #ifdef MUROARD_FEATURE_DAEMONIZE
  int daemon = 0;
 #endif
@@ -266,6 +271,10 @@ int muroard_main_initonly (int argc, char * argv[]) {
                                      .codec = MUROAR_CODEC_PCM_S};
 #endif
 
+#ifndef MUROARD_FEATURE_ARGV
+ (void)argc, (void)argv;
+#endif
+
  muroard_para_init(muroard_g_state);
 
 #ifdef MUROARD_FEATURE_ARGV
@@ -274,6 +283,7 @@ int muroard_main_initonly (int argc, char * argv[]) {
 
 #ifdef MUROARD_FEATURE_HELP_TEXT
   if ( !strcmp(k, "--help") || !strcmp(k, "-h") ) {
+   __check_argc(0)
    muroard_usage();
    return 0;
 #else
@@ -282,39 +292,53 @@ int muroard_main_initonly (int argc, char * argv[]) {
 #endif
 #ifdef MUROARD_FEATURE_VERSION_TEXT
   } else if ( !strcmp(k, "--version") ) {
+   __check_argc(0)
    muroard_version();
    return 0;
 #endif
 #ifdef MUROARD_FEATURE_DAEMONIZE
   } else if ( !strcmp(k, "--daemon") ) {
+   __check_argc(0)
    daemon = 1;
 #endif
 #ifdef MUROARD_FEATURE_STANDBY
   } else if ( !strcmp(k, "--autostandby") ) {
+   __check_argc(0)
    muroard_waveform_standby(-1, 1);
   } else if ( !strcmp(k, "--no-autostandby") ) {
+   __check_argc(0)
    muroard_waveform_standby(-1, 0);
   } else if ( !strcmp(k, "--standby") ) {
+   __check_argc(0)
    muroard_waveform_standby(1, -1);
   } else if ( !strcmp(k, "--no-standby") ) {
+   __check_argc(0)
    muroard_waveform_standby(0, -1);
 #endif
   } else if ( !strcmp(k, "--rate") || !strcmp(k, "-R") ) {
+   __check_argc(1)
    muroard_state_member(sa_rate) = atoi(argv[++i]);
   } else if ( !strcmp(k, "--channels") || !strcmp(k, "-C") ) {
+   __check_argc(1)
    muroard_state_member(sa_channels) = atoi(argv[++i]);
   } else if ( !strcmp(k, "--odevice") || !strcmp(k, "-O") ) {
+   __check_argc(1)
    o_dev  = argv[++i];
 #ifdef MUROARD_FEATURE_SOURCES
   } else if ( !strcmp(k, "-S") ) {
+   __check_argc(1)
    s_filename = argv[++i];
   } else if ( !strcmp(k, "-sC") ) {
+   __check_argc(1)
    s_info.channels = atoi(argv[++i]);
   } else if ( !strcmp(k, "-sB") ) {
+   __check_argc(1)
    s_info.bits = atoi(argv[++i]);
   } else if ( !strcmp(k, "-sE") ) {
+   __check_argc(1)
    s_info.codec = atoi(argv[++i]);
   } else if ( !strcmp(k, "-sD") ) {
+   __check_argc(1)
    i++;
    if ( !strcmp(argv[i], "in") ) {
     s_dir = STREAM_DATADIR_IN;
@@ -340,28 +364,35 @@ int muroard_main_initonly (int argc, char * argv[]) {
 #endif
 #ifdef MUROARD_FEATURE_SOCKET_LISTEN
   } else if ( !strcmp(k, "--no-listen") ) {
+   __check_argc(0)
    n_no_listen = 1;
 #endif
 #ifdef MUROARD_FEATURE_CLIENT_FH
   } else if ( !strcmp(k, "--client-fh") ) {
+   __check_argc(1)
    c_sock[c_sock_count++] = atoi(argv[++i]);
 #endif
 #ifdef MUROARD_FEATURE_SOCKET_LISTEN
   } else if ( !strcmp(k, "--bind") ) {
+   __check_argc(1)
    n_addr = argv[++i];
   } else if ( !strcmp(k, "--port") ) {
+   __check_argc(1)
    n_port = atoi(argv[++i]);
 #ifdef MUROARD_FEATURE_SOCKET_UNIX
   } else if ( !strcmp(k, "--unix") || !strcmp(k, "-u") ) {
-    n_type = MUROARD_NETWORK_TYPE_UNIX;
+   __check_argc(0)
+   n_type = MUROARD_NETWORK_TYPE_UNIX;
 #endif
 #ifdef MUROARD_FEATURE_SOCKET_INET
   } else if ( !strcmp(k, "--tcp") || !strcmp(k, "-t") ) {
-    n_type = MUROARD_NETWORK_TYPE_INET;
+   __check_argc(0)
+   n_type = MUROARD_NETWORK_TYPE_INET;
 #endif
 #ifdef MUROARD_FEATURE_SOCKET_DECNET
   } else if ( !strcmp(k, "--decnet") || !strcmp(k, "-n") ) {
-    n_type = MUROARD_NETWORK_TYPE_DECNET;
+   __check_argc(0)
+   n_type = MUROARD_NETWORK_TYPE_DECNET;
 #endif
 #endif
   } else {
@@ -413,7 +444,7 @@ int muroard_main_initonly (int argc, char * argv[]) {
  muroard_init_signals();
 #endif
 
-#ifdef MUROARD_FEATURE_DAEMONIZE
+#if defined(MUROARD_FEATURE_DAEMONIZE) && defined(MUROARD_FEATURE_ARGV)
  if ( daemon ) {
   muroard_daemonize();
  }
