@@ -1,7 +1,7 @@
 //streams.c:
 
 /*
- *      Copyright (C) Philipp 'ph3-der-loewe' Schafft - 2010-2011
+ *      Copyright (C) Philipp 'ph3-der-loewe' Schafft - 2010-2013
  *
  *  This file is part of RoarD,
  *  a sound server daemon for using the RoarAudio protocol.
@@ -251,8 +251,13 @@ int muroard_stream_new(int client, int dir, struct muroard_audio_info * info) {
 
    memcpy(&(stream->info), info, sizeof(stream->info));
 
+   if ( client_set_stream(client, i) == -1 ) {
+    if ( stream->iobuf != NULL )
+     muroard_free(stream->iobuf);
+    return -1;
+   }
+
    stream->state = STREAM_STATE_NEW;
-   client_set_stream(client, i); // TODO: check errors here
    return i;
   }
  }
@@ -500,6 +505,10 @@ int muroard_stream_move_client(int id, int client) {
  if ( muroard_state_member(stream)[id].state == STREAM_STATE_UNUSED )
   return -1;
 
+ // check if the target client will accept the stream.
+ if ( client_set_stream_check(client, id) == -1 )
+  return -1;
+
  old_client = muroard_state_member(stream)[id].client;
 
  // if we are execed we need to close the client, too.
@@ -529,7 +538,7 @@ int muroard_stream_move_client(int id, int client) {
 #endif
 
  muroard_state_member(stream)[id].client = client;
- client_set_stream(client, id); // TODO: check errors here
+ client_set_stream(client, id); // errors are checked above.
 
  return 0;
 }
@@ -642,14 +651,19 @@ int muroard_stream_new_source(const char * filename, int dir, struct muroard_aud
 #endif
  int fh;
 
- if ( dir == STREAM_DATADIR_IN ) {
-  flags |= O_RDONLY;
- } else if ( dir == STREAM_DATADIR_OUT ) {
+ switch (dir) {
+  case STREAM_DATADIR_IN:
+    flags |= O_RDONLY;
+   break;
+  case STREAM_DATADIR_OUT:
 #ifndef O_LARGEFILE
 #define O_LARGEFILE 0
 #endif
-  flags |= O_WRONLY|O_CREAT|O_LARGEFILE|O_APPEND;
- } else {
+    flags |= O_WRONLY|O_CREAT|O_LARGEFILE|O_APPEND;
+   break;
+  default:
+    return -1;
+   break;
  }
 
  fh = open(filename, flags, 0666);
